#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-lib
version:              0.3
visibility:           public
id:                   test-lib-0.3-7VN1d0joBCzAswslOfZdc7
key:                  test-lib-0.3-7VN1d0joBCzAswslOfZdc7
license:              ISC
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A library to make a quick test-runner script.
description:
    This library makes it easy to define an executable,
    which can find and run a bunch of tests for a binary.

category:             Testing
abi:                  0ea03a50e3dac86f3afe42cffe0a6fd0
exposed:              True
exposed-modules:      TestLib
hidden-modules:       Paths_test_lib
import-dirs:          /usr/lib/ghc-8.10.5/site-local/test-lib-0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/test-lib-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/test-lib-0.3
hs-libraries:         HStest-lib-0.3-7VN1d0joBCzAswslOfZdc7
depends:
    HUnit-1.6.2.0-8FsjWfKzSV74wDnwnuEJe4 base-4.14.2.0
    containers-0.6.4.1 directory-1.3.6.0 filepath-1.4.2.1
    process-1.6.9.0 simple-get-opt-0.4-EOtqP13rrNoKxKzoxk8b26
    test-framework-0.8.2.0-5eYG3NRKVE7L7pW0FKysaQ
    test-framework-hunit-0.3.0.2-6EN5DaB9gXBAvhheezcely

haddock-interfaces:   /usr/share/doc/haskell-test-lib/html/test-lib.haddock
haddock-html:         /usr/share/doc/haskell-test-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

